# Roadmap

Knexpy is still under development, however some features are still yet to be implemented.

On the pipeline:

1. *Left Join*
2. *Right Join*
3. *Inner Join*
4. *Outer Join*
5. *Join*
6. *Group By*
7. *Offset*
8. Abstract more WHERE clauses
